Index: src/crankshaft/x87/lithium-x87.cc |
diff --git a/src/crankshaft/x87/lithium-x87.cc b/src/crankshaft/x87/lithium-x87.cc |
index 635916dc53396021ab0116dff9dc3dc63933a953..51d9cd697b1a716a8e37996111f0daeb0de93faf 100644 |
--- a/src/crankshaft/x87/lithium-x87.cc |
+++ b/src/crankshaft/x87/lithium-x87.cc |
@@ -925,10 +925,12 @@ void LChunkBuilder::AddInstruction(LInstruction* instr, |
DCHECK_NOT_NULL(hydrogen_env); |
if (instr->IsSyntacticTailCall()) { |
// If it was a syntactic tail call we need to drop the current frame and |
// an arguments adaptor frame on top of it (if the latter is present). |
hydrogen_env = hydrogen_env->outer(); |
- if (hydrogen_env != nullptr && |
- hydrogen_env->frame_type() == ARGUMENTS_ADAPTOR) { |
+ while (hydrogen_env != nullptr && |
+ (hydrogen_env->frame_type() == ARGUMENTS_ADAPTOR || |
+ hydrogen_env->frame_type() == TAIL_CALLER_FUNCTION)) { |
hydrogen_env = hydrogen_env->outer(); |
} |
if (hydrogen_env != nullptr) { |
@@ -925,10 +925,12 @@ void LChunkBuilder::AddInstruction(LInstruction* instr, |
if (instr->IsSyntacticTailCall()) { |
// If it was a syntactic tail call we need to drop the current frame and |
- // an arguments adaptor frame on top of it (if the latter is present). |
+ // all the frames on top of it that are either an arguments adaptor frame |
+ // or a tail caller frame. |
hydrogen_env = hydrogen_env->outer(); |